/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.user.model

import android.os.Parcelable
import com.kakao.sdk.partner.auth.model.AgeAuthLevel
import kotlinx.android.parcel.Parcelize
import java.util.*

/**
 *
 * @property id 인증 여부를 확인하는 user의 id
 * @property auth_level 유저가 받은 인증레벨. AUTH_LEVEL1, AUTH_LEVEL2 중 하나.
 * @property authLevelCode 1 (auth_level : AUTH_LEVEL1) / 2 (auth_level : AUTH_LEVEL2)
 * @property bypassAgeLimit true : 인증 받은 연령이 제한 나이 이상 / false : 인증 받은 연령이 제한 나이 미만
 * @property authenticatedAt 인증 받은 시각. RFC3339 internet date/time format
 * @property ciNeedsAgreement 사용자 동의를 받으면 ci를 가지고 갈 수 있는지 여부
 * @property ci 인증후 받은 CI 값
 *
 */
@Parcelize
data class AgeAuthInfo(
    val id: Long?,
    val authLevel: AgeAuthLevel?,
    val authLevelCode: Int?,
    val bypassAgeLimit: Boolean?,
    val authenticatedAt: Date?,
    val ciNeedsAgreement: Boolean?,
    val ci: String?
) : Parcelable